@@ -10,17 +10,17 @@ class SortPool(tf.keras.Model):
     OOP API for SortPool "An End-to-End Deep Learning Architecture for Graph Classification"
     """
 
-    def __init__(self, K=None, ratio=None, sort_index=-1,  *args, **kwargs):
+    def __init__(self, k=None, ratio=None, sort_index=-1, *args, **kwargs):
         """
         SAGPool
 
         :param score_gnn: A GNN model to score nodes for the pooling, [x, edge_index, edge_weight] => node_score.
-        :param K: Keep top K targets for each source
+        :param k: Keep top k targets for each source
         :param ratio: Keep num_targets * ratio targets for each source
         :param sort_index: The sort_index_th index of the last axis will used for sort.
         """
         super().__init__(*args, **kwargs)
-        self.K = K
+        self.k = k
         self.ratio = ratio
         self.sort_index = sort_index
 
@@ -33,4 +33,4 @@ class SortPool(tf.keras.Model):
         x, edge_index, edge_weight, node_graph_index = inputs
 
         return sort_pool(x, edge_index, edge_weight, node_graph_index,
-                         K=self.K, ratio=self.ratio, sort_index=self.sort_index, training=training)
+                         k=self.k, ratio=self.ratio, sort_index=self.sort_index, training=training)
