@@ -1,6 +1,7 @@
 # coding=utf-8
 import tensorflow as tf
-from tf_geometric.sparse.sparse_adj import SparseAdj
+# from tf_geometric.sparse.sparse_adj import SparseAdj
+from tf_sparse import SparseMatrix
 
 
 def gin_updater(x, reduced_neighbor_msg, eps):
@@ -28,7 +29,7 @@ def gin(x, edge_index, mlp_model, eps=0.0, training=None):
     # h = gin_updater(x, h, eps)
 
     num_nodes = tf.shape(x)[0]
-    sparse_adj = SparseAdj(edge_index, shape=[num_nodes, num_nodes])
+    sparse_adj = SparseMatrix(edge_index, shape=[num_nodes, num_nodes])
 
     neighbor_h = sparse_adj @ x
     h = x * (1.0 + eps) + neighbor_h
